@@ -481,7 +481,23 @@ struct TensorListView<Backend, DataType, DynamicDimensions>
   TensorListView &operator=(const TensorListView &) = default;
   TensorListView &operator=(TensorListView &&) = default;
 
-  //@{
+  /** @{ */
+  /** @brief Construction from contiguous memory */
+
+  TensorListView(std::nullptr_t, const std::vector<TensorShape<DynamicDimensions>> &shapes)
+      : Base(TensorListShape<DynamicDimensions>(shapes)) {}
+
+  template <int other_sample_ndim>
+  TensorListView(std::nullptr_t, const TensorListShape<other_sample_ndim> &shape)
+      : Base(shape) {}
+
+  template <int other_sample_ndim>
+  TensorListView(std::nullptr_t, TensorListShape<other_sample_ndim> &&shape)
+      : Base(std::move(shape)) {}
+
+  /** @} */
+
+  /** @{ */
   /** @brief  Construction from contiguous memory */
 
   TensorListView(DataType *data, const std::vector<TensorShape<DynamicDimensions>> &shapes)
@@ -495,9 +511,9 @@ struct TensorListView<Backend, DataType, DynamicDimensions>
   TensorListView(DataType *data, TensorListShape<other_sample_ndim> &&shape)
       : Base(data, std::move(shape)) {}
 
-  //@}
+  /** @} */
 
-  //@{
+  /** @{ */
   /** @brief Construction from non-contiguous memory */
 
   TensorListView(DataType *const *data, const std::vector<TensorShape<DynamicDimensions>> &shapes)
@@ -519,9 +535,9 @@ struct TensorListView<Backend, DataType, DynamicDimensions>
   TensorListView(data_pointers_t &&data, TensorListShape<other_sample_ndim> &&shape)
       : Base(std::move(data), std::move(shape)) {}
 
-  //@}
+  /** @} */
 
-  //@{
+  /** @{ */
   /** @brief Implicit conversion */
 
   template <int other_sample_ndim, typename U>
@@ -536,7 +552,7 @@ struct TensorListView<Backend, DataType, DynamicDimensions>
     detail::check_implicit_conversion<U, DataType>();
   }
 
-  //@}
+  /** @} */
 };
 
 template <typename Backend, typename DataType, int sample_ndim>
@@ -549,7 +565,7 @@ struct TensorListView : TensorListViewBase<Backend, DataType, sample_ndim> {
   TensorListView &operator=(const TensorListView &) = default;
   TensorListView &operator=(TensorListView &&) = default;
 
-  //@{
+  /** @{ */
   /** @brief Construction from contiguous memory */
 
   TensorListView(std::nullptr_t, const std::vector<TensorShape<sample_ndim>> &shapes)
@@ -563,9 +579,9 @@ struct TensorListView : TensorListViewBase<Backend, DataType, sample_ndim> {
   TensorListView(std::nullptr_t, TensorListShape<other_sample_ndim> &&shape)
       : Base(std::move(shape)) {}
 
-  //@}
+  /** @} */
 
-  //@{
+  /** @{ */
   /** @brief Construction from contiguous memory */
 
   TensorListView(DataType *data, const std::vector<TensorShape<sample_ndim>> &shapes)
@@ -579,9 +595,9 @@ struct TensorListView : TensorListViewBase<Backend, DataType, sample_ndim> {
   TensorListView(DataType *data, TensorListShape<other_sample_ndim> &&shape)
       : Base(data, std::move(shape)) {}
 
-  //@}
+  /** @} */
 
-  //@{
+  /** @{ */
   /** @brief Construction from non-contiguous memory */
 
   TensorListView(DataType *const *data, const std::vector<TensorShape<sample_ndim>> &shapes)
@@ -601,9 +617,9 @@ struct TensorListView : TensorListViewBase<Backend, DataType, sample_ndim> {
   TensorListView(data_pointers_t &&data, TensorListShape<sample_ndim> &&shape)
       : Base(std::move(data), std::move(shape)) {}
 
-  //@}
+  /** @} */
 
-  //@{
+  /** @{ */
   /** @brief Implicit conversion */
 
   template <typename U, int other_sample_ndim>
@@ -619,7 +635,7 @@ struct TensorListView : TensorListViewBase<Backend, DataType, sample_ndim> {
     detail::check_implicit_conversion<U, DataType>();
   }
 
-  //@}
+  /** @} */
 };
 
 struct StorageCPU;
@@ -650,6 +666,31 @@ TensorListView<StorageBackend, T, ndim> make_tensor_list(T *const *data,
   return { data, std::move(shape) };
 }
 
+/**
+ * @brief Wraps a TensorView into a TensorListView.
+ */
+template <typename StorageBackend, int ndim, typename T>
+TensorListView<StorageBackend, T, ndim> make_tensor_list(
+    const TensorView<StorageBackend, T, ndim> &tv) {
+  return {tv.data, {tv.shape}};
+}
+
+/**
+ * @brief Creates a TensorListView from the vector of TensorLists.
+ */
+template<typename StorageBackend, int ndim, typename T>
+TensorListView<StorageBackend, T, ndim> make_tensor_list(
+        const std::vector<TensorView<StorageBackend, T, ndim>> &tvs) {
+  if (tvs.empty()) return {};
+  TensorListView<StorageBackend, T, ndim> tlv;
+  tlv.resize(tvs.size(), tvs[0].dim());
+  for (size_t i = 0; i < tvs.size(); i++) {
+    tlv.shape.set_tensor_shape(i, tvs[i].shape);
+    tlv.data[i] = tvs[i].data;
+  }
+  return tlv;
+}
+
 /**
  * @brief Wraps CPU raw memory as a tensor
  */
@@ -700,8 +741,8 @@ TensorListView<StorageGPU, T, ndim> make_tensor_list_gpu(T *const *data,
   return { data, std::move(shape) };
 }
 
+/** @{ */
 /**
- * @{
  * @brief Get a subtensor by slicing along the outermost dimension at position `pos`
  *
  * @details Produces a tensor with the outermost extent removed,
@@ -733,9 +774,7 @@ subtensor(TensorView<StorageBackend, DataType, DynamicDimensions> source, int64_
   DataType *data = source.data + pos * volume(shape);
   return make_tensor<StorageBackend>(data, std::move(shape));
 }
-/**
- * @}
- */
+/** @} */
 
 /**
  * @brief Merges a dimension with the next one
